@@ -1,7 +1,7 @@
 package Screensaver::Any;
 
-our $DATE = '2018-02-28'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2019-09-03'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -60,6 +60,22 @@ _
 sub detect_screensaver {
     my %args = @_;
 
+    require Proc::Find;
+    no warnings 'once';
+    local $Proc::Find::CACHE = 1;
+
+  XSCREENSAVER:
+    {
+        log_trace "Checking whether xscreensaver process exists ...";
+        unless (Proc::Find::proc_exists(name => "xscreensaver")) {
+            log_trace "xscreensaver process doesn't exist";
+            last;
+        }
+        log_trace "xscreensaver process exists";
+        log_trace "Concluding screensaver is xscreensaver";
+        return "xscreensaver";
+    }
+
   KDE:
     {
         log_trace "Checking qdbus program ...";
@@ -79,10 +95,6 @@ sub detect_screensaver {
         return "kde";
     }
 
-    require Proc::Find;
-    no warnings 'once';
-    local $Proc::Find::CACHE = 1;
-
   GNOME:
     {
         log_trace "Checking whether gnome-screensaver process exists ...";
@@ -107,18 +119,6 @@ sub detect_screensaver {
         return "cinnamon";
     }
 
-  XSCREENSAVER:
-    {
-        log_trace "Checking whether xscreensaver process exists ...";
-        unless (Proc::Find::proc_exists(name => "xscreensaver")) {
-            log_trace "xscreensaver process doesn't exist";
-            last;
-        }
-        log_trace "xscreensaver process exists";
-        log_trace "Concluding screensaver is xscreensaver";
-        return "xscreensaver";
-    }
-
     undef;
 }
 
@@ -351,7 +351,7 @@ sub enable_screensaver {
         if ($?) { return [500, "Failed"] } else { return [200, "OK"] }
     }
 
-    [501, "Not yet implemented"];
+    [501, "Not yet implemented except for gnome-screensaver"];
 }
 
 $SPEC{disable_screensaver} = {
@@ -370,7 +370,7 @@ sub disable_screensaver {
         if ($?) { return [500, "Failed"] } else { return [200, "OK"] }
     }
 
-    [501, "Not yet implemented"];
+    [501, "Not yet implemented except for gnome-screensaver"];
 }
 
 $SPEC{activate_screensaver} = {
@@ -568,7 +568,7 @@ Screensaver::Any - Common interface to screensaver/screenlocker functions
 
 =head1 VERSION
 
-This document describes version 0.004 of Screensaver::Any (from Perl distribution Screensaver-Any), released on 2018-02-28.
+This document describes version 0.005 of Screensaver::Any (from Perl distribution Screensaver-Any), released on 2019-09-03.
 
 =head1 DESCRIPTION
 
@@ -595,7 +595,7 @@ command like C<< dbus-send --type=method_call --dest=org.gnome.ScreenSaver
 
 Usage:
 
- activate_screensaver(%args) -> [status, msg, result, meta]
+ activate_screensaver(%args) -> [status, msg, payload, meta]
 
 Activate screensaver immediately and lock screen.
 
@@ -618,18 +618,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 deactivate_screensaver
 
 Usage:
 
- deactivate_screensaver(%args) -> [status, msg, result, meta]
+ deactivate_screensaver(%args) -> [status, msg, payload, meta]
 
 Deactivate screensaver and unblank the screen.
 
@@ -661,13 +662,14 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 detect_screensaver
 
 Usage:
@@ -687,11 +689,12 @@ No arguments.
 Return value:  (str)
 
 
+
 =head2 disable_screensaver
 
 Usage:
 
- disable_screensaver(%args) -> [status, msg, result, meta]
+ disable_screensaver(%args) -> [status, msg, payload, meta]
 
 Disable screensaver so screen will not go blank or lock after being idle.
 
@@ -714,18 +717,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 enable_screensaver
 
 Usage:
 
- enable_screensaver(%args) -> [status, msg, result, meta]
+ enable_screensaver(%args) -> [status, msg, payload, meta]
 
 Enable screensaver that has been previously disabled.
 
@@ -748,18 +752,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 get_screensaver_timeout
 
 Usage:
 
- get_screensaver_timeout(%args) -> [status, msg, result, meta]
+ get_screensaver_timeout(%args) -> [status, msg, payload, meta]
 
 Get screensaver idle timeout, in number of seconds.
 
@@ -782,18 +787,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value: Timeout value, in seconds (float)
 
 
+
 =head2 prevent_screensaver_activated
 
 Usage:
 
- prevent_screensaver_activated() -> [status, msg, result, meta]
+ prevent_screensaver_activated() -> [status, msg, payload, meta]
 
 Prevent screensaver from being activated by resetting idle timer.
 
@@ -817,18 +823,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 screensaver_is_active
 
 Usage:
 
- screensaver_is_active(%args) -> [status, msg, result, meta]
+ screensaver_is_active(%args) -> [status, msg, payload, meta]
 
 Check if screensaver is being activated.
 
@@ -851,18 +858,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 set_screensaver_timeout
 
 Usage:
 
- set_screensaver_timeout(%args) -> [status, msg, result, meta]
+ set_screensaver_timeout(%args) -> [status, msg, payload, meta]
 
 Set screensaver idle timeout.
 
@@ -931,7 +939,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -959,7 +967,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
